@@ -222,19 +222,19 @@ gnome_canvas_hacktext_destroy (GtkObject *object)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
-void
+static void
 art_drect_hacktext (ArtDRect *bbox, GnomeCanvasHacktext *hacktext)
 {
 	GnomeCanvasHacktextCharInfo *info;
 	double x, y;
-	char *text;
+	const unsigned char *text;
 	int i;
 	ArtDRect w_bbox;
 	double affine[6];
 
 	x = hacktext->x;
 	y = hacktext->y;
-	text = hacktext->text;
+	text = (const unsigned char *)hacktext->text;
 	if (text == NULL)
 		return;
 
@@ -312,6 +312,7 @@ get_bounds_canvas (GnomeCanvasHacktext *hacktext, double *bx1, double *by1, doub
 	*by2 = bbox_canvas.y1 + 1;
 }
 
+#if 0
 static void
 recalc_bounds (GnomeCanvasHacktext *hacktext)
 {
@@ -352,6 +353,7 @@ recalc_bounds (GnomeCanvasHacktext *hacktext)
 
 	gnome_canvas_group_child_bounds (GNOME_CANVAS_GROUP (item->parent), item);
 }
+#endif
 
 /* Convenience function to set a GC's foreground color to the specified pixel value */
 static void
@@ -662,9 +664,6 @@ static void
 gnome_canvas_hacktext_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int flags)
 {
 	GnomeCanvasHacktext *hacktext;
-	ArtVpath *vpath;
-	ArtSVP *svp;
-	double width;
 	double x1, y1, x2, y2;
 	ArtIRect ibbox = {0, 0, 0, 0};
 
@@ -815,10 +814,8 @@ gnome_canvas_hacktext_point (GnomeCanvasItem *item, double mx, double my,
 	GnomeCanvasHacktext *hacktext;
 	GnomeCanvasHacktextCharInfo *info;
 	double x, y, width;
-	char *text;
+	const unsigned char *text;
 	int i;
-	ArtDRect w_bbox;
-	ArtIRect wi_bbox, int_rect;
 	ArtBpath *affine_bpath;
 	ArtVpath *vpath;
 	ArtSVP *svp;
@@ -827,11 +824,13 @@ gnome_canvas_hacktext_point (GnomeCanvasItem *item, double mx, double my,
 	hacktext = GNOME_CANVAS_HACKTEXT (item);
 	x = hacktext->x;
 	y = hacktext->y;
-	text = hacktext->text;
-	if (text == NULL) {
-		/* This failed to return a value.  MW.  */
-		return 0.0;
-	}
+	text = (const unsigned char *)hacktext->text;
+	if (text == NULL)
+		return 100.0;
+
+	/* If we get the empty string, this default will be used.  FIXME: check
+	   sanity.  */
+	dist = 100.0;
 
 	art_affine_scale (size_affine, hacktext->size * 0.001, hacktext->size * -0.001);
 	art_affine_multiply (affine, size_affine, hacktext->priv->affine);
@@ -952,16 +951,15 @@ gnome_canvas_hacktext_req_repaint (GnomeCanvasHacktext *hacktext,
 {
 	GnomeCanvasHacktextCharInfo *info;
 	double x, y;
-	char *text;
+	const unsigned char *text;
 	int i;
-	ArtDRect i_bbox;
 	ArtDRect w_bbox;
 	ArtIRect wbi;
 	double size_affine[6], affine[6];
 
 	x = hacktext->x;
 	y = hacktext->y;
-	text = hacktext->text;
+	text = (const unsigned char *)hacktext->text;
 	if (text == NULL)
 		return;
 
@@ -991,7 +989,7 @@ gnome_canvas_hacktext_render (GnomeCanvasItem *item,
 	GnomeCanvasHacktext *hacktext;
 	GnomeCanvasHacktextCharInfo *info;
 	double x, y, width;
-	char *text;
+	const unsigned char *text;
 	int i;
 	ArtDRect w_bbox;
 	ArtIRect wi_bbox, int_rect;
@@ -1016,7 +1014,7 @@ gnome_canvas_hacktext_render (GnomeCanvasItem *item,
 	hacktext = GNOME_CANVAS_HACKTEXT (item);
 	x = hacktext->x;
 	y = hacktext->y;
-	text = hacktext->text;
+	text = (const unsigned char *)hacktext->text;
 	if (text == NULL)
 		return;
 
