@@ -856,10 +856,10 @@ gnome_font_load_afm (GnomeFontMap *fontmap_entry)
 
 /* Return the amount of kerning for the two glyphs. */
 double
-gnome_font_kern (GnomeFont *font, int glyph1, int glyph2)
+gnome_font_kern (const GnomeFont *font, int glyph1, int glyph2)
 {
   int ktabsize;
-  GnomeFontKernPair *ktab;
+  const GnomeFontKernPair *ktab;
   int j;
     
   ktabsize = font->fontmap_entry->num_kerns;
@@ -874,10 +874,10 @@ gnome_font_kern (GnomeFont *font, int glyph1, int glyph2)
 
 /* Return the amount of kerning for the two glyphs. */
 int
-gnome_font_unsized_kern (GnomeFontUnsized *font, int glyph1, int glyph2)
+gnome_font_unsized_kern (const GnomeFontUnsized *font, int glyph1, int glyph2)
 {
   int ktabsize;
-  GnomeFontKernPair *ktab;
+  const GnomeFontKernPair *ktab;
   int j;
     
   ktabsize = font->num_kerns;
@@ -1044,8 +1044,8 @@ gnome_font_new_closest (const char *family_name,
 
 
 /* return a pointer to the (PostScript) name of the font */
-char *
-gnome_font_unsized_get_name (GnomeFontUnsized *font)
+const char *
+gnome_font_unsized_get_name (const GnomeFontUnsized *font)
 {
   g_return_val_if_fail (font != NULL, NULL);
 
@@ -1053,8 +1053,8 @@ gnome_font_unsized_get_name (GnomeFontUnsized *font)
 }
 
 /* return a pointer to the (PostScript) name of the font */
-char *
-gnome_font_unsized_get_glyph_name (GnomeFontUnsized *font)
+const char *
+gnome_font_unsized_get_glyph_name (const GnomeFontUnsized *font)
 {
   g_return_val_if_fail (font != NULL, NULL);
 
@@ -1065,8 +1065,8 @@ gnome_font_unsized_get_glyph_name (GnomeFontUnsized *font)
 }
 
 /* return a pointer to the (PostScript) name of the font */
-char *
-gnome_font_get_name (GnomeFont *font)
+const char *
+gnome_font_get_name (const GnomeFont *font)
 {
   g_return_val_if_fail (font != NULL, NULL);
 
@@ -1074,10 +1074,10 @@ gnome_font_get_name (GnomeFont *font)
 }
 
 /* return a pointer to the (PostScript) name of the font */
-char *
-gnome_font_get_glyph_name (GnomeFont *font)
+const char *
+gnome_font_get_glyph_name (const GnomeFont *font)
 {
-  GnomeFontMap *fontmap_entry;
+  const GnomeFontMap *fontmap_entry;
 
   g_return_val_if_fail (font != NULL, NULL);
 
@@ -1173,12 +1173,12 @@ pfb_to_flat (const char *input, int input_size)
 }
 
 char *
-gnome_font_unsized_get_pfa (GnomeFontUnsized *font)
+gnome_font_unsized_get_pfa (const GnomeFontUnsized *font)
 {
-  char *pfb_fn;
+  const char *pfb_fn;
   FILE *f;
 #if 0
-  GnomeFontMap *subst;
+  const GnomeFontMap *subst;
 #endif
 
   char *pfb;
@@ -1237,13 +1237,13 @@ gnome_font_unsized_get_pfa (GnomeFontUnsized *font)
 }
 
 char *
-gnome_font_get_pfa (GnomeFont *font)
+gnome_font_get_pfa (const GnomeFont *font)
 {
   return gnome_font_unsized_get_pfa (font->fontmap_entry);
 }
 
 double
-gnome_font_get_width (GnomeFont *font, int ch)
+gnome_font_get_width (const GnomeFont *font, int ch)
 {
   if (ch < 0 || ch >= 256)
     return 0.0;
@@ -1252,7 +1252,7 @@ gnome_font_get_width (GnomeFont *font, int ch)
 
 /* Returns the glyph width in 0.001 unit */
 int
-gnome_font_unsized_get_width (GnomeFontUnsized *font, int ch)
+gnome_font_unsized_get_width (const GnomeFontUnsized *font, int ch)
 {
   if (ch < 0 || ch >= 256)
     return 0;
@@ -1271,7 +1271,7 @@ gnome_font_unsized_get_width (GnomeFontUnsized *font, int ch)
  * Returns: the length of the string @s using the @font.
  */
 double
-gnome_font_get_width_string (GnomeFont *font, const char *s)
+gnome_font_get_width_string (const GnomeFont *font, const char *s)
 {
   unsigned char *us = (unsigned char *)s;
   int *widths = font->fontmap_entry->widths;
@@ -1298,7 +1298,7 @@ gnome_font_get_width_string (GnomeFont *font, const char *s)
  * the @font.
  */
 double
-gnome_font_get_width_string_n (GnomeFont *font, const char *s, int n)
+gnome_font_get_width_string_n (const GnomeFont *font, const char *s, int n)
 {
   unsigned char *us = (unsigned char *)s;
   int const * const widths = font->fontmap_entry->widths;
@@ -1311,7 +1311,7 @@ gnome_font_get_width_string_n (GnomeFont *font, const char *s, int n)
 /* Get the glyph number corresponding to a given unicode, or -1 if it
    is not mapped. */
 int
-gnome_font_unsized_get_glyph (GnomeFontUnsized *font, int unicode)
+gnome_font_unsized_get_glyph (const GnomeFontUnsized *font, int unicode)
 {
   int page;
   int *cov_page;
@@ -1330,7 +1330,7 @@ gnome_font_unsized_get_glyph (GnomeFontUnsized *font, int unicode)
 /* Get the glyph number corresponding to a given unicode, or -1 if it
    is not mapped. */
 int
-gnome_font_get_glyph (GnomeFont *font, int unicode)
+gnome_font_get_glyph (const GnomeFont *font, int unicode)
 {
   return gnome_font_unsized_get_glyph (font->fontmap_entry, unicode);
 }
@@ -1371,8 +1371,8 @@ gnome_font_list_free (GList *fontlist)
 }
 
 /* These two should probably go into the class */
-GHashTable *gnome_font_family_hash = NULL;
-GList *gnome_font_family_the_list = NULL;
+static GHashTable *gnome_font_family_hash = NULL;
+static GList *gnome_font_family_the_list = NULL;
 
 /* Return a list of font families, as a g_list of newly allocated strings */
 GList *
@@ -1398,7 +1398,6 @@ gnome_font_family_list (GnomeFontClass *class)
 	  the_family = g_list_prepend (NULL, &fontmap[i]);
 	  g_hash_table_insert (hash, fontmap[i].familyname, the_family);
 	  list = g_list_append (list, fontmap[i].familyname);
-
 	}
       else
 	g_list_append (the_family, &fontmap[i]);
@@ -1592,7 +1591,7 @@ initialize_hashes (void)
 }
 
 
-const char *
+static const char *
 gnome_font_family_to_x_name (const char *family)
 {
   const char *x_name;
@@ -1606,7 +1605,7 @@ gnome_font_family_to_x_name (const char *family)
 }
 
 
-const char *
+static const char *
 gnome_font_x_name_to_family (const char *x_name)
 {
   const char *family;
