@@ -123,56 +123,56 @@ gnome_font_unsized_closest (const char *family_name,
 			    gboolean italic);
 
 /* return a pointer to the (PostScript) name of the font */
-char *
-gnome_font_unsized_get_name (GnomeFontUnsized *font);
+const char *
+gnome_font_unsized_get_name (const GnomeFontUnsized *font);
 
 /* return a pointer to the (PostScript) name of the font */
-char *
-gnome_font_unsized_get_glyph_name (GnomeFontUnsized *font);
+const char *
+gnome_font_unsized_get_glyph_name (const GnomeFontUnsized *font);
+
+const char *
+gnome_font_get_name (const GnomeFont *font);
+
+const char *
+gnome_font_get_glyph_name (const GnomeFont *font);
 
 char *
-gnome_font_get_name (GnomeFont *font);
+gnome_font_unsized_get_pfa (const GnomeFontUnsized *font);
 
 char *
-gnome_font_get_glyph_name (GnomeFont *font);
-
-char *
-gnome_font_unsized_get_pfa (GnomeFontUnsized *font);
-
-char *
-gnome_font_get_pfa (GnomeFont *font);
+gnome_font_get_pfa (const GnomeFont *font);
 
 /* this routine is fast; go ahead and use it */
 double
-gnome_font_get_width (GnomeFont *font, int ch);
+gnome_font_get_width (const GnomeFont *font, int ch);
 
 /* Returns the glyph width in 0.001 unit */
 int
-gnome_font_unsized_get_width (GnomeFontUnsized *font, int ch);
+gnome_font_unsized_get_width (const GnomeFontUnsized *font, int ch);
 
 /* these routines are fast; go ahead and use them */
 double
-gnome_font_get_width_string (GnomeFont *font, const char *s);
+gnome_font_get_width_string (const GnomeFont *font, const char *s);
 double
-gnome_font_get_width_string_n (GnomeFont *font, const char *s, int n);
+gnome_font_get_width_string_n (const GnomeFont *font, const char *s, int n);
 
 /* Return the amount of kerning for the two glyphs. */
 double
-gnome_font_kern (GnomeFont *font, int glyph1, int glyph2);
+gnome_font_kern (const GnomeFont *font, int glyph1, int glyph2);
 
 /* Return the amount of kerning for the two glyphs. */
 int
-gnome_font_unsized_kern (GnomeFontUnsized *font, int glyph1, int glyph2);
+gnome_font_unsized_kern (const GnomeFontUnsized *font, int glyph1, int glyph2);
 
 /* Get the glyph number corresponding to a given unicode, or -1 if it
    is not mapped. */
 int
-gnome_font_get_glyph (GnomeFont *font, int unicode);
+gnome_font_get_glyph (const GnomeFont *font, int unicode);
 
 /* Get the glyph number corresponding to a given unicode, or -1 if it
    is not mapped. */
 int
-gnome_font_unsized_get_glyph (GnomeFontUnsized *font, int unicode);
+gnome_font_unsized_get_glyph (const GnomeFontUnsized *font, int unicode);
 
 /* Return a list of fonts, as a g_list of strings */
 GList *
