@@ -112,7 +112,7 @@ encode_double (GnomePrintContext *pc, double d)
 	static int message_shown;
 
 	if (!message_shown){
-		g_warning ("We lack double marshalling\n");
+		g_warning ("We lack marshalling of type `double'\n");
 		message_shown = 1;
 	}
 	encode_block (GNOME_PRINT_META (pc), sizeof (double), &d); 
@@ -226,7 +226,7 @@ meta_setlinecap (GnomePrintContext *pc, int captype)
 }
 
 static int
-meta_setdash (GnomePrintContext *pc, int n_values, double *values, double offset)
+meta_setdash (GnomePrintContext *pc, int n_values, const double *values, double offset)
 {
 	int i;
 	
@@ -256,8 +256,8 @@ meta_stroke (GnomePrintContext *pc)
 static int
 meta_setfont (GnomePrintContext *pc, GnomeFont *font)
 {
-	char *fontname = font->fontmap_entry->font_name;
-	int  len = strlen (fontname);
+	const char *fontname = font->fontmap_entry->font_name;
+	int len = strlen (fontname);
 			  
 	encode_int (pc, GNOME_META_SETFONT);
 	encode_double (pc, font->size);
@@ -280,7 +280,7 @@ meta_show (GnomePrintContext *pc, char const *text)
 }
 
 static int
-meta_concat (GnomePrintContext *pc, double matrix [6])
+meta_concat (GnomePrintContext *pc, const double matrix [6])
 {
 	encode_int (pc, GNOME_META_CONCAT);
 	encode_six_doubles (pc, matrix [0], matrix [1], matrix [2], matrix [3], matrix [4], matrix [5]);
@@ -288,7 +288,7 @@ meta_concat (GnomePrintContext *pc, double matrix [6])
 }
 
 static int
-meta_setmatrix (GnomePrintContext *pc, double matrix [6])
+meta_setmatrix (GnomePrintContext *pc, const double matrix [6])
 {
 	encode_int (pc, GNOME_META_SETMATRIX);
 	encode_six_doubles (pc, matrix [0], matrix [1], matrix [2], matrix [3], matrix [4], matrix [5]);
@@ -324,7 +324,7 @@ meta_eoclip (GnomePrintContext *pc)
 }
 
 static void
-encode_image (GnomePrintContext *pc, char *data, int width, int height, int rowstride, int bytes_per_pixel)
+encode_image (GnomePrintContext *pc, const char *data, int width, int height, int rowstride, int bytes_per_pixel)
 {
 	int ix, y;
 	
@@ -339,7 +339,7 @@ encode_image (GnomePrintContext *pc, char *data, int width, int height, int rows
 }
 
 static int
-meta_grayimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+meta_grayimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
 	encode_int (pc, GNOME_META_GRAYIMAGE);
 	encode_image (pc, data, width, height, rowstride, 1);
@@ -347,7 +347,7 @@ meta_grayimage (GnomePrintContext *pc, char *data, int width, int height, int ro
 }
 
 static int
-meta_rgbimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+meta_rgbimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
 	encode_int (pc, GNOME_META_RGBIMAGE);
 	encode_image (pc, data, width, height, rowstride, 3);
@@ -492,15 +492,15 @@ gnome_print_meta_new (void)
  * GNOME_METAFILE stream.
  */
 GnomePrintMeta *
-gnome_print_meta_new_from (void *data)
+gnome_print_meta_new_from (const void *data)
 {
 	GnomePrintMeta *meta;
-	GnomeMetaFileHeader *mf = data;
+	const GnomeMetaFileHeader *mf = data;
 	int len;
 
 	g_return_val_if_fail (data != NULL, NULL);
 
-	if (strcmp ((char *)data, GNOME_METAFILE_SIGNATURE) != 0)
+	if (strcmp ((const char *)data, GNOME_METAFILE_SIGNATURE) != 0)
 		return NULL;
 
 	len = mf->size;
@@ -841,25 +841,26 @@ do_render (GnomePrintContext *dest, const char *data, int size, int page)
  * Returns TRUE on success.
  */
 gboolean
-gnome_print_meta_render (GnomePrintContext *destination, void *meta_stream)
+gnome_print_meta_render (GnomePrintContext *destination, const void *meta_stream)
 {
-	char *data;
-	int size;
-	
+	const char *data;
+	const GnomeMetaFileHeader *header;
+
 	g_return_val_if_fail (destination != NULL, FALSE);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (destination), FALSE);
 	g_return_val_if_fail (meta_stream != NULL, FALSE);
 
-	if (strcmp ((char *) meta_stream, GNOME_METAFILE_SIGNATURE) != 0)
+	data = meta_stream;
+	if (strcmp (data, GNOME_METAFILE_SIGNATURE) != 0)
 		return FALSE;
 
-	if (((GnomeMetaFileHeader *)meta_stream)->size == -1){
+	header = meta_stream;
+	if (header->size == -1){
 		g_warning ("This stream was not closed");
 		return FALSE;
 	}
-	data = meta_stream;
-	size = ((GnomeMetaFileHeader *)meta_stream)->size;
-	return do_render (destination, data + sizeof (GnomeMetaFileHeader), size, -1);
+
+	return do_render (destination, data + sizeof (GnomeMetaFileHeader), header->size, -1);
 }
 
 /**
@@ -873,7 +874,7 @@ gnome_print_meta_render (GnomePrintContext *destination, void *meta_stream)
  * Returns TRUE on success.
  */
 gboolean
-gnome_print_meta_render_from_object (GnomePrintContext *destination, GnomePrintMeta *source)
+gnome_print_meta_render_from_object (GnomePrintContext *destination, const GnomePrintMeta *source)
 {
 	g_return_val_if_fail (destination != NULL, FALSE);
 	g_return_val_if_fail (source != NULL, FALSE);
@@ -895,26 +896,26 @@ gnome_print_meta_render_from_object (GnomePrintContext *destination, GnomePrintM
  * Returns TRUE on success.
  */
 gboolean
-gnome_print_meta_render_page (GnomePrintContext *destination, void *meta_stream, int page)
+gnome_print_meta_render_page (GnomePrintContext *destination, const void *meta_stream, int page)
 {
-	char *data;
-	int size;
+	const char *data;
+	const GnomeMetaFileHeader *header;
 	
 	g_return_val_if_fail (destination != NULL, FALSE);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (destination), FALSE);
 	g_return_val_if_fail (meta_stream != NULL, FALSE);
 
-	if (strcmp ((char *) meta_stream, GNOME_METAFILE_SIGNATURE) != 0)
+	data = meta_stream;
+	if (strcmp (data, GNOME_METAFILE_SIGNATURE) != 0)
 		return FALSE;
 
-	data = meta_stream;
-	size = ((GnomeMetaFileHeader *)meta_stream)->size;
-
-	if (size == -1){
+	header = meta_stream;
+	if (header->size == -1){
 		g_warning ("This printing context has not been closed");
 		return FALSE;
 	}
-	return do_render (destination, data + sizeof (GnomeMetaFileHeader), size, page);
+
+	return do_render (destination, data + sizeof (GnomeMetaFileHeader), header->size, page);
 }
 
 /**
@@ -929,7 +930,7 @@ gnome_print_meta_render_page (GnomePrintContext *destination, void *meta_stream,
  * Returns TRUE on success.
  */
 gboolean
-gnome_print_meta_render_from_object_page (GnomePrintContext *destination, GnomePrintMeta *source, int page)
+gnome_print_meta_render_from_object_page (GnomePrintContext *destination, const GnomePrintMeta *source, int page)
 {
 	g_return_val_if_fail (destination != NULL, FALSE);
 	g_return_val_if_fail (source != NULL, FALSE);
@@ -940,7 +941,7 @@ gnome_print_meta_render_from_object_page (GnomePrintContext *destination, GnomeP
 }
 
 int
-gnome_print_meta_pages (GnomePrintMeta *meta)
+gnome_print_meta_pages (const GnomePrintMeta *meta)
 {
 	g_return_val_if_fail (meta != NULL, 0);
 	g_return_val_if_fail (GNOME_IS_PRINT_META (meta), 0);
