@@ -33,7 +33,7 @@ typedef struct {
 
 GtkType         gnome_print_meta_get_type (void);
 GnomePrintMeta *gnome_print_meta_new      (void);
-GnomePrintMeta *gnome_print_meta_new_from (void *data);
+GnomePrintMeta *gnome_print_meta_new_from (const void *data);
 
 /* Returns the value in GnomePrinterMeta structure, shared with the object */
 int             gnome_print_meta_access_buffer (GnomePrintMeta *meta,
@@ -43,20 +43,20 @@ int             gnome_print_meta_get_copy      (GnomePrintMeta *meta,
 						void **bufer, int *buflen);
 
 /* Returns the number of pages generated */
-int             gnome_print_meta_pages         (GnomePrintMeta *meta);
+int             gnome_print_meta_pages         (const GnomePrintMeta *meta);
 
 /*
  * Rendering a metafile into a GnomePrintContext
  */
 
 gboolean gnome_print_meta_render_from_object      (GnomePrintContext *destination,
-						   GnomePrintMeta *source);
+						   const GnomePrintMeta *source);
 gboolean gnome_print_meta_render                  (GnomePrintContext *destination,
-						   void *meta_stream);
+						   const void *meta_stream);
 gboolean gnome_print_meta_render_page             (GnomePrintContext *destination,
-						   void *meta_stream, int page);
+						   const void *meta_stream, int page);
 gboolean gnome_print_meta_render_from_object_page (GnomePrintContext *destination,
-						   GnomePrintMeta *source, int page);
+						   const GnomePrintMeta *source, int page);
 
 #ifdef __cplusplus
 }
