@@ -77,7 +77,7 @@ struct _GnomePrintPreviewPrivate {
 static GnomePrintContextClass *print_preview_parent_class;
 
 static void
-gc_set_dash (GraphicContext *ctx, int n_values, double *values, double offset)
+gc_set_dash (GraphicContext *ctx, int n_values, const double *values, double offset)
 {
 	ctx->dash_n_values = n_values;
 	ctx->dash_values   = g_new (double, n_values);
@@ -426,7 +426,7 @@ gpp_setlinecap (GnomePrintContext *pc, int captype)
 }
 
 static int
-gpp_setdash (GnomePrintContext *pc, int n_values, double *values, double offset)
+gpp_setdash (GnomePrintContext *pc, int n_values, const double *values, double offset)
 {
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
 	GnomePrintPreviewPrivate *priv = pp->priv;
@@ -455,7 +455,7 @@ gpp_setfont (GnomePrintContext *pc, GnomeFont *font)
 }
 
 static int
-gpp_concat (GnomePrintContext *pc, double matrix [6])
+gpp_concat (GnomePrintContext *pc, const double matrix [6])
 {
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
 	GnomePrintPreviewPrivate *priv = pp->priv;
@@ -466,7 +466,7 @@ gpp_concat (GnomePrintContext *pc, double matrix [6])
 }
 
 static int
-gpp_setmatrix (GnomePrintContext *pc, double matrix[6])
+gpp_setmatrix (GnomePrintContext *pc, const double matrix[6])
 {
 	g_warning ("setmatrix is deprecated");
 
@@ -561,7 +561,7 @@ gpp_eoclip (GnomePrintContext *pc)
 }
 
 static int
-gpp_image (GnomePrintContext *pc, char *data, int width, int height, int rowstride, int bytes_per_pixel)
+gpp_image (GnomePrintContext *pc, const char *data, int width, int height, int rowstride, int bytes_per_pixel)
 {
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
 	GnomePrintPreviewPrivate *priv = pp->priv;
@@ -591,7 +591,8 @@ gpp_image (GnomePrintContext *pc, char *data, int width, int height, int rowstri
 		memcpy (dup, data, size);
 		pixbuf = art_pixbuf_new_rgba (dup, width, height, rowstride);
 	} else if (bytes_per_pixel == 1){
-		char *source, *target;
+		const char *source;
+		char *target;
 		int  ix, iy;
 
 		source = data;
@@ -640,13 +641,13 @@ gpp_image (GnomePrintContext *pc, char *data, int width, int height, int rowstri
 }
 
 static int
-gpp_grayimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+gpp_grayimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
 	return  gpp_image (pc, data, width, height, rowstride, 1);
 }
 
 static int
-gpp_rgbimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+gpp_rgbimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
 	return gpp_image (pc, data, width, height, rowstride, 3);
 }
@@ -690,7 +691,7 @@ gpp_showpage (GnomePrintContext *pc)
 }
 
 static Gt1LoadedFont *
-fetch_font (GnomePrintPreviewPrivate *priv, char *pfb_file, char *afm_file)
+fetch_font (GnomePrintPreviewPrivate *priv, const char *pfb_file, const char *afm_file)
 {
 	Gt1LoadedFont *font;
 	
