@@ -2,9 +2,11 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <math.h>
+#include <ctype.h>
 
 #include <libart_lgpl/art_affine.h>
 #include <libgnomeprint/gnome-print-ps.h>
+#include <libgnomeprint/gnome-font.h>
 
 
 static void gnome_print_ps_class_init (GnomePrintPsClass *klass);
@@ -167,7 +169,7 @@ gnome_print_ps_setlinecap (GnomePrintContext *pc, int captype)
 }
 
 static int
-gnome_print_ps_setdash (GnomePrintContext *pc, int n_values, double *values, double offset)
+gnome_print_ps_setdash (GnomePrintContext *pc, int n_values, const double *values, double offset)
 {
   int i, res;
 
@@ -199,7 +201,7 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
   GnomePrintPs *ps;
   char *pfa;
   int i;
-  char *fontname;
+  const char *fontname;
 
   g_return_val_if_fail (pc != NULL, -1);
 
@@ -231,7 +233,7 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
 	  if (ps->n_fonts == ps->n_fonts_max)
 	    ps->fonts = g_realloc (ps->fonts, sizeof (char *) *
 				   (ps->n_fonts_max <<= 1));
-	  ps->fonts[ps->n_fonts++] = fontname;
+	  ps->fonts[ps->n_fonts++] = g_strdup (fontname);
 	  g_free (pfa);
 	}
     }
@@ -242,6 +244,7 @@ gnome_print_ps_setfont_raw (GnomePrintContext *pc, GnomeFontUnsized *unsized,
 
   ps->current_font = fontname;
   ps->current_font_size = size;
+  /* FIXME: what about ->current_gnome_font?  */
 
   return gnome_print_context_fprintf (pc,
 				      "/%s findfont %g scalefont setfont\n",
@@ -256,7 +259,7 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
   GnomePrintPs *ps;
   char *pfa;
   int i;
-  char *fontname;
+  const char *fontname;
 
   g_return_val_if_fail (pc != NULL, -1);
 
@@ -288,7 +291,7 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 	  if (ps->n_fonts == ps->n_fonts_max)
 	    ps->fonts = g_realloc (ps->fonts, sizeof (char *) *
 				   (ps->n_fonts_max <<= 1));
-	  ps->fonts[ps->n_fonts++] = fontname;
+	  ps->fonts[ps->n_fonts++] = g_strdup (fontname);
 	  g_free (pfa);
 	}
     }
@@ -302,6 +305,9 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 
   ps->current_font = fontname;
   ps->current_font_size = font->size;
+  ps->current_gnome_font = font;
+  /* FIXME: should we ref the font or are we guaranteed to have it around
+     for long enough?  */
 
   /* invalidate the settings for gnome-text */
   ps->cur_font = 0;
@@ -317,29 +323,39 @@ static int
 gnome_print_ps_show (GnomePrintContext *pc, char const *text)
 {
   int i;
+  GnomePrintPs *ps;
+  ps = GNOME_PRINT_PS (pc);
 
   if (gnome_print_context_fprintf (pc, "(") < 0)
     return -1;
   for (i = 0; text[i]; i++)
     {
-      /* todo: maybe we should test for non-ascii characters here, and
-	 format as octal */
       if (text[i] == '(' || text[i] == ')' || text[i] == '\\') 
 	{
 	  if (gnome_print_context_fprintf (pc, "\\%c", text[i]) < 0)
 	    return -1;
 	}
-      else
+      else if (isascii (text[i]))
 	{
 	  if (gnome_print_context_fprintf (pc, "%c", text[i]) < 0)
 	    return -1;
 	}
+      else
+	{
+	  int c;
+	  c = gnome_font_get_glyph (ps->current_gnome_font,
+				    (unsigned char)(text[i]));
+	  if (c == -1)
+	    c = '*'; /* FIXME -- do something better for missing chars.  */
+	  if (gnome_print_context_fprintf (pc, "%c", c) < 0)
+	    return -1;
+	}
     }
   return gnome_print_context_fprintf (pc, ") show\n");
 }
 
 static int
-gnome_print_ps_concat (GnomePrintContext *pc, double matrix[6])
+gnome_print_ps_concat (GnomePrintContext *pc, const double matrix[6])
 {
   char str[128];
 
@@ -349,7 +365,7 @@ gnome_print_ps_concat (GnomePrintContext *pc, double matrix[6])
 }
 
 static int
-gnome_print_ps_setmatrix (GnomePrintContext *pc, double matrix[6])
+gnome_print_ps_setmatrix (GnomePrintContext *pc, const double matrix[6])
 {
   return gnome_print_context_fprintf (pc,
                                       "[ %g %g %g %g %g %g ] setmatrix\n",
@@ -389,8 +405,9 @@ gnome_print_ps_eoclip (GnomePrintContext *pc)
                                       "eoclip\n");
 }
 
-static static int
-gnome_print_ps_image (GnomePrintContext *pc, char *data, int width, int height, int rowstride, int bytes_per_pixel)
+static int
+gnome_print_ps_image (GnomePrintContext *pc, const char *data, int width, int height,
+		      int rowstride, int bytes_per_pixel)
 {
   int status;
   char linebuf[80];
@@ -458,13 +475,13 @@ gnome_print_ps_image (GnomePrintContext *pc, char *data, int width, int height,
 }
 
 static int
-gnome_print_ps_grayimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+gnome_print_ps_grayimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
   return  gnome_print_ps_image (pc, data, width, height, rowstride, 1);
 }
 
 static int
-gnome_print_ps_rgbimage (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+gnome_print_ps_rgbimage (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
   return gnome_print_ps_image (pc, data, width, height, rowstride, 3);
 }
@@ -700,26 +717,33 @@ gnome_print_ps_new (GnomePrinter *printer)
 
   ps = gtk_type_new (gnome_print_ps_get_type ());
 
-  gnome_print_context_open_file (GNOME_PRINT_CONTEXT (ps), printer->filename);
+  if (!gnome_print_context_open_file (GNOME_PRINT_CONTEXT (ps), printer->filename))
+    goto failure;
 
   pc = GNOME_PRINT_CONTEXT (ps);
 
-  gnome_print_context_fprintf (pc,
-			       "%%!PS-Adobe-2.0\n"
-			       "%%%% Creator: Gnome Print Version %s\n"
-			       "%%%% DocumentName: %s\n"
-			       "%%%% Author: %s\n"
-			       "%%%%EndComments\n\n\n",
-			       VERSION,
-			       "Document Name Goes Here",
-			       "Author Goes Here");
+  if (gnome_print_context_fprintf (pc,
+				   "%%!PS-Adobe-2.0\n"
+				   "%%%% Creator: Gnome Print Version %s\n"
+				   "%%%% DocumentName: %s\n"
+				   "%%%% Author: %s\n"
+				   "%%%%EndComments\n\n\n",
+				   VERSION,
+				   "Document Name Goes Here",
+				   "Author Goes Here") < 0)
+    goto failure;
   return ps;
+
+ failure:
+  gtk_object_unref (GTK_OBJECT (ps));
+  return NULL;
 }
 
 
 static void
 gnome_print_ps_finalize (GtkObject *object)
 {
+  int i;
   GnomePrintPs *ps;
 
   g_return_if_fail (object != NULL);
@@ -727,7 +751,10 @@ gnome_print_ps_finalize (GtkObject *object)
 
   ps = GNOME_PRINT_PS (object);
 
+  for (i = 0; i < ps->n_fonts; i++)
+    g_free (ps->fonts[i]);
   g_free (ps->fonts);
+  g_free (ps->builtins);
 
   (* GTK_OBJECT_CLASS (parent_class)->finalize) (object);
 }
