@@ -97,11 +97,13 @@ gnome_print_context_init (GnomePrintContext *pc)
 GnomePrintContext *
 gnome_print_context_new_with_paper_size (GnomePrinter *printer, const char *paper_size)
 {
-	if (strcmp (printer->driver, "gnome-print-ps") == 0)
-		return GNOME_PRINT_CONTEXT (gnome_print_ps_new (printer));
+	if (strcmp (printer->driver, "gnome-print-ps") == 0) {
+		GnomePrintPs *ps = gnome_print_ps_new (printer);
+		return ps ? GNOME_PRINT_CONTEXT (ps) : NULL;
+	}
 
 	if (strncmp (printer->driver, "gnome-print-uni", strlen ("gnome-print-uni")) == 0)
-		return GNOME_PRINT_CONTEXT (gnome_print_pixbuf_new (printer, paper_size, 75));
+		return gnome_print_pixbuf_new (printer, paper_size, 75);
 
 	return NULL;
 }
@@ -210,7 +212,7 @@ gnome_print_setlinecap       (GnomePrintContext *pc, int captype)
 }
 
 int
-gnome_print_setdash          (GnomePrintContext *pc, int n_values, double *values, double offset)
+gnome_print_setdash          (GnomePrintContext *pc, int n_values, const double *values, double offset)
 {
   return PRINT_CLASS(pc)->setdash (pc, n_values, values, offset);
 }
@@ -240,13 +242,13 @@ gnome_print_show             (GnomePrintContext *pc, char const *text)
 }
 
 int
-gnome_print_concat           (GnomePrintContext *pc, double matrix[6])
+gnome_print_concat           (GnomePrintContext *pc, const double matrix[6])
 {
   return PRINT_CLASS(pc)->concat (pc, matrix);
 }
 
 int
-gnome_print_setmatrix        (GnomePrintContext *pc, double matrix[6])
+gnome_print_setmatrix        (GnomePrintContext *pc, const double matrix[6])
 {
   return PRINT_CLASS(pc)->setmatrix (pc, matrix);
 }
@@ -276,13 +278,13 @@ gnome_print_eoclip           (GnomePrintContext *pc)
 }
 
 int
-gnome_print_grayimage        (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+gnome_print_grayimage        (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
   return PRINT_CLASS(pc)->grayimage (pc, data, width, height, rowstride);
 }
 
 int
-gnome_print_rgbimage         (GnomePrintContext *pc, char *data, int width, int height, int rowstride)
+gnome_print_rgbimage         (GnomePrintContext *pc, const char *data, int width, int height, int rowstride)
 {
   return PRINT_CLASS(pc)->rgbimage (pc, data, width, height, rowstride);
 }
