@@ -66,7 +66,7 @@ struct _GnomePrintContextClass
 
   int (* setlinecap)       (GnomePrintContext *pc, int captype);
 
-  int (* setdash)          (GnomePrintContext *pc, int n_values, double *values, double offset);
+  int (* setdash)          (GnomePrintContext *pc, int n_values, const double *values, double offset);
 
   int (* strokepath)       (GnomePrintContext *pc);
 
@@ -76,9 +76,9 @@ struct _GnomePrintContextClass
 
   int (* show)             (GnomePrintContext *pc, char const *text);
 
-  int (* concat)           (GnomePrintContext *pc, double matrix[6]);
+  int (* concat)           (GnomePrintContext *pc, const double matrix[6]);
 
-  int (* setmatrix)        (GnomePrintContext *pc, double matrix[6]);
+  int (* setmatrix)        (GnomePrintContext *pc, const double matrix[6]);
 
   int (* gsave)            (GnomePrintContext *pc);
 
@@ -88,9 +88,9 @@ struct _GnomePrintContextClass
 
   int (* eoclip)           (GnomePrintContext *pc);
 
-  int (* grayimage)        (GnomePrintContext *pc, char *data, int width, int height, int rowstride);
+  int (* grayimage)        (GnomePrintContext *pc, const char *data, int width, int height, int rowstride);
 
-  int (* rgbimage)         (GnomePrintContext *pc, char *data, int width, int height, int rowstride);
+  int (* rgbimage)         (GnomePrintContext *pc, const char *data, int width, int height, int rowstride);
 
   int (* textline)	   (GnomePrintContext *pc, GnomeTextLine *line);
 
@@ -146,7 +146,7 @@ int
 gnome_print_setlinecap       (GnomePrintContext *pc, int captype);
 
 int
-gnome_print_setdash          (GnomePrintContext *pc, int n_values, double *values, double offset);
+gnome_print_setdash          (GnomePrintContext *pc, int n_values, const double *values, double offset);
 
 int
 gnome_print_strokepath       (GnomePrintContext *pc);
@@ -161,10 +161,10 @@ int
 gnome_print_show             (GnomePrintContext *pc, char const *text);
 
 int
-gnome_print_concat           (GnomePrintContext *pc, double matrix[6]);
+gnome_print_concat           (GnomePrintContext *pc, const double matrix[6]);
 
 int
-gnome_print_setmatrix        (GnomePrintContext *pc, double matrix[6]);
+gnome_print_setmatrix        (GnomePrintContext *pc, const double matrix[6]);
 
 int
 gnome_print_gsave            (GnomePrintContext *pc);
@@ -179,10 +179,10 @@ int
 gnome_print_eoclip           (GnomePrintContext *pc);
 
 int
-gnome_print_grayimage        (GnomePrintContext *pc, char *data, int width, int height, int rowstride);
+gnome_print_grayimage        (GnomePrintContext *pc, const char *data, int width, int height, int rowstride);
 
 int
-gnome_print_rgbimage         (GnomePrintContext *pc, char *data, int width, int height, int rowstride);
+gnome_print_rgbimage         (GnomePrintContext *pc, const char *data, int width, int height, int rowstride);
 
 int
 gnome_print_textline	     (GnomePrintContext *pc, GnomeTextLine *line);
