@@ -28,7 +28,7 @@ struct _GnomePrinterProfile {
 };
 
 static void
-gnome_printer_load_profiles_from (char *filename, GnomePrinterProfileList **list)
+gnome_printer_load_profiles_from (const char *filename, GnomePrinterProfileList **list)
 {
 	char *base_prefix, *name;
 	int base_len;
@@ -68,7 +68,7 @@ gnome_printer_load_profiles_from (char *filename, GnomePrinterProfileList **list
 }
 
 static void
-gnome_printer_load_profiles_from_dir (char *dirname, GnomePrinterProfileList **list)
+gnome_printer_load_profiles_from_dir (const char *dirname, GnomePrinterProfileList **list)
 {
 	DIR *dir;
 	struct dirent *dent;
@@ -259,7 +259,7 @@ gnome_printer_profile_get_output (GnomePrinterProfile *pp)
 }
 
 static GnomePrinter *
-gnome_printer_create (char *file, char *driver)
+gnome_printer_create (const char *file, const char *driver)
 {
 	GnomePrinter *printer;
 	
@@ -280,7 +280,9 @@ gnome_printer_create (char *file, char *driver)
  * they modify the printer profile's default setting for output.
  */
 GnomePrinter *
-gnome_printer_profile_get_printer (GnomePrinterProfile *pp, char *optional_file, char *optional_command)
+gnome_printer_profile_get_printer (GnomePrinterProfile *pp,
+				   const char *optional_file,
+				   const char *optional_command)
 {
 	GnomePrinter *printer = NULL;
 	char *output = NULL;
