@@ -16,6 +16,6 @@ struct _Gt1NameContext {
 
 Gt1NameContext *gt1_name_context_new (void);
 void gt1_name_context_free (Gt1NameContext *nc);
-Gt1NameId gt1_name_context_intern (Gt1NameContext *nc, char *name);
-Gt1NameId gt1_name_context_intern_size (Gt1NameContext *nc, char *name, int size);
+Gt1NameId gt1_name_context_intern (Gt1NameContext *nc, const char *name);
+Gt1NameId gt1_name_context_intern_size (Gt1NameContext *nc, const char *name, int size);
 char *gt1_name_context_string (Gt1NameContext *nc, Gt1NameId Gt1NameId);
