@@ -175,10 +175,10 @@ tokenize_new_from_mystring (MyGt1String *input)
 static TokenType
 tokenize_get (Gt1TokenContext *tc, MyGt1String *result)
 {
-  char *s = tc->source;
+  unsigned char *s = (unsigned char *)tc->source;
   int index = tc->index;
   int pos = tc->pos;
-  char c;
+  unsigned char c;
   TokenType type;
 
   /* skip comments altogether (maybe later we want them, though) */
@@ -325,7 +325,7 @@ tokenize_get (Gt1TokenContext *tc, MyGt1String *result)
 }
 
 static int
-ascii_to_hex (char c)
+ascii_to_hex (unsigned char c)
 {
   if (c <= '9') return c - '0';
   else if (c >= 'a') return c + 10 - 'a';
@@ -338,7 +338,7 @@ ascii_to_hex (char c)
 static int
 tokenize_get_hex_byte (Gt1TokenContext *tc)
 {
-  char *s = tc->source;
+  const unsigned char *s = (const unsigned char *)tc->source;
   int index = tc->index;
   int pos = tc->pos;
   int byte;
@@ -513,9 +513,9 @@ parse_num (MyGt1String *number)
   int exp_sign;
   int exp;
   int i, length;
-  char *start;
+  const unsigned char *start;
 
-  start = number->start;
+  start = (const unsigned char *)number->start;
   length = number->fin - number->start;
 
   i = 0;
@@ -563,7 +563,7 @@ parse_num (MyGt1String *number)
 	  exp = (exp * 10) + start[i] - '0';
 	  i++;
 	}
-      mantissa *= pow (10, exp * sign);
+      mantissa *= pow (10, exp * exp_sign);
     }
   return sign * mantissa;
 }
